@@ -329,8 +329,24 @@ sub send_sess_message{
 sub parse_send_status_msg{
     my $self = shift;
     my $json = shift;
-    if(defined $json and $json->{errCode}==0){
-        return $self->new_send_status(code=>0,msg=>"发送成功"); 
+    if(defined $json){
+        if(exists $json->{errCode} and $json->{errCode}==0){
+            if(exists $json->{msg} and $json->{msg} eq 'send ok'){
+                return $self->new_send_status(code=>0,msg=>"发送成功");
+            }
+            elsif(exists $json->{errMsg}){
+                return $self->new_send_status(code=>-3,msg=>"发送失败");
+            }
+            else{
+                return $self->new_send_status(code=>-4,msg=>"发送失败");
+            }
+        }
+        elsif(exists $json->{retcode} and $json->{retcode}==0){
+            return $self->new_send_status(code=>0,msg=>"发送成功");
+        }
+        else{
+            return $self->new_send_status(code=>-2,msg=>"发送失败");
+        }
     }
     else{
         return $self->new_send_status(code=>-1,msg=>"发送失败"); 
@@ -529,9 +545,11 @@ sub parse_receive_msg {
         $self->poll_failure_count( ++$poll_failure_count);
         $self->warn( "获取消息失败，当前失败次数: ". $self->poll_failure_count. "\n" );
         if ( $self->poll_failure_count > $self->poll_failure_count_max ) {
-            $self->warn("接收消息失败次数超过最大值，尝试进行重新连接...\n");
             $self->poll_failure_count(0);
-            $self->_relink();
+            #$self->warn("接收消息失败次数超过最大值，尝试进行重新连接...\n");
+            #$self->_relink();
+            $self->warn("接收消息失败次数超过最大值，尝试进行重新登录...\n");
+            $self->relogin();
         }
     }
 
